# Live Edit Schema Form Examples

This page contains examples of the different fields provided by Schema Form in Horizon. The `Schema` and `Form` sections below can be edited inline to customise the form output. For further documentation on Schema Form, see http://schemaform.io/.

## Form Output

{$ ctrl.schema.title $}

## Model

    {$ ctrl.prettyModelData() $}

## Select Example

## Schema

Use the schema to describe the data model and valid input patterns. A schema is always JSON. NOTE: A schema element is not needed for items that have no data model, like sections and fieldsets.

{{ ctrl.schemaError }}

## Form

Use the form to set titles, descriptions and choose specific UI element types for each schema item. In the form builder, the form must be JSON, but you can use JavaScript in production code, such as `gettext` for translation.

{{ ctrl.formError }}